@@ -10,7 +10,7 @@ package Devel::Cover::Criterion;
 use strict;
 use warnings;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 use Devel::Cover::Statement;
 use Devel::Cover::Branch;
@@ -36,8 +36,7 @@ sub text        { "n/a" }
 sub values      { [ $_[0]->covered ] }
 sub criterion   { require Carp; Carp::confess("criterion() must be overridden") }
 
-sub calculate_percentage
-{
+sub calculate_percentage {
     my $class = shift;
     my ($db, $s) = @_;
     my $errors = $s->{error} || 0;
@@ -55,8 +54,7 @@ sub aggregate {
     $s->{Total}{total}{$keyword} += $t;
 }
 
-sub calculate_summary
-{
+sub calculate_summary {
     my $self = shift;
     my ($db, $file) = @_;
 
@@ -78,7 +76,7 @@ Devel::Cover::Criterion - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
