@@ -20,11 +20,10 @@ use Devel::Cover::Dumper;
 # For comprehensive debug logging.
 use constant DEBUG => 0;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 our $AUTOLOAD;
 
-sub new
-{
+sub new {
     my $class = shift;
     my $self  = { @_ };
     bless $self, $class
@@ -32,8 +31,7 @@ sub new
 
 sub DESTROY {}
 
-sub AUTOLOAD
-{
+sub AUTOLOAD {
     my $self = $_[0];
     my $func = $AUTOLOAD;
     $func =~ s/.*:://;
@@ -43,32 +41,23 @@ sub AUTOLOAD
                grep $_ eq $criterion, @Devel::Cover::DB::Criteria,
                                       qw( sub_name file line );
     no strict "refs";
-    if ($function eq "get")
-    {
+    if ($function eq "get") {
         my $c = $criterion eq "time" ? "statement" : $criterion;
-        if (grep $_ eq $c, qw( sub_name file line ))
-        {
+        if (grep $_ eq $c, qw( sub_name file line )) {
             *$func = sub { shift->{$c} };
-        }
-        else
-        {
-            *$func = sub
-            {
+        } else {
+            *$func = sub {
                 my $self   = shift;
                 my $digest = shift;
                 # print STDERR "file: $digest, condition: $c\n";
-                for my $fval (values %{$self->{f}})
-                {
+                for my $fval (values %{$self->{f}}) {
                     return $fval->{$c} if $fval->{digest} eq $digest;
                 }
                 return
             }
         };
-    }
-    else
-    {
-        *$func = sub
-        {
+    } else {
+        *$func = sub {
             my $self = shift;
             my $file = shift;
             push @{$self->{f}{$file}{$criterion}}, @_;
@@ -80,8 +69,7 @@ sub AUTOLOAD
 sub debuglog {
     my $self = shift;
     my $dir = "$self->{base}/debuglog";
-    unless (mkdir $dir)
-    {
+    unless (mkdir $dir) {
         confess "Can't mkdir $dir: $!" unless -d $dir;
     }
 
@@ -95,21 +83,18 @@ sub debuglog {
     close $fh or confess "Can't close $dir/$$: $!";
 }
 
-sub add_criteria
-{
+sub add_criteria {
     my $self = shift;
     @{$self->{criteria}}{@_} = ();
     $self
 }
 
-sub criteria
-{
+sub criteria {
     my $self = shift;
     keys %{$self->{criteria}}
 }
 
-sub set_subroutine
-{
+sub set_subroutine {
     my $self = shift;
     my ($sub_name, $file, $line, $scount) =
        @{$self}{qw( sub_name file line scount )} = @_;
@@ -124,32 +109,25 @@ sub set_subroutine
     # print STDERR "set_subroutine start $file:$line $sub_name($scount) ",
                  # Dumper $self->{f}{$file}{start};
     $self->{additional} = 0;
-    if ($self->reuse($file))
-    {
+    if ($self->reuse($file)) {
         # reusing a structure
-        if (exists $self->{f}{$file}{start}{$line}{$sub_name}[$scount])
-        {
+        if (exists $self->{f}{$file}{start}{$line}{$sub_name}[$scount]) {
             # sub already exists - normal case
             # print STDERR "reuse $file:$line:$sub_name\n";
             $self->{count}{$_}{$file} =
                 $self->{f}{$file}{start}{$line}{$sub_name}[$scount]{$_}
                 for $self->criteria;
-        }
-        else
-        {
+        } else {
             # sub doesn't exist, for example a conditional C<eval "use M">
             $self->{additional} = 1;
-            if (exists $self->{additional_count}{($self->criteria)[0]}{$file})
-            {
+            if (exists $self->{additional_count}{($self->criteria)[0]}{$file}) {
                 # already had such a sub in module
                 # print STDERR "reuse additional $file:$line:$sub_name\n";
                 $self->{count}{$_}{$file} =
                     $self->{f}{$file}{start}{$line}{$sub_name}[$scount]{$_} =
                     ($self->add_count($_))[0]
                     for $self->criteria;
-            }
-            else
-            {
+            } else {
                 # first such a sub in module
                 # print STDERR "reuse first $file:$line:$sub_name\n";
                 $self->{count}{$_}{$file} =
@@ -159,9 +137,7 @@ sub set_subroutine
                     for $self->criteria;
             }
         }
-    }
-    else
-    {
+    } else {
         # first time sub seen in new structure
         # print STDERR "new $file:$line:$sub_name\n";
         $self->{count}{$_}{$file} =
@@ -173,8 +149,7 @@ sub set_subroutine
                  # Dumper $self->{f}{$file}{start};
 }
 
-sub store_counts
-{
+sub store_counts {
     my $self = shift;
     my ($file) = @_;
     $self->{count}{$_}{$file} =
@@ -184,22 +159,19 @@ sub store_counts
     # print STDERR "store_counts: ", Dumper $self->{f}{$file}{start};
 }
 
-sub reuse
-{
+sub reuse {
     my $self = shift;
     my ($file) = @_;
     exists $self->{f}{$file}{start}{-1}{"__COVER__"}
     # TODO - exists $self->{f}{$file}{start}{-1}
 }
 
-sub set_file
-{
+sub set_file {
     my $self = shift;
     my ($file) = @_;
     $self->{file} = $file;
     my $digest = $self->digest($file);
-    if ($digest)
-    {
+    if ($digest) {
         # print STDERR "Adding $digest for $file\n";
         $self->{f}{$file}{digest} = $digest;
         push @{$self->{digests}{$digest}}, $file;
@@ -207,21 +179,17 @@ sub set_file
     $digest
 }
 
-sub digest
-{
+sub digest {
     my $self = shift;
     my ($file) = @_;
 
     # print STDERR "Opening $file for MD5 digest\n";
 
     my $digest;
-    if (open my $fh, "<", $file)
-    {
+    if (open my $fh, "<", $file) {
         binmode $fh;
         $digest = Digest::MD5->new->addfile($fh)->hexdigest;
-    }
-    else
-    {
+    } else {
         print STDERR "Devel::Cover: Warning: can't open $file " .
                                              "for MD5 digest: $!\n"
             unless lc $file eq "-e" or
@@ -232,15 +200,13 @@ sub digest
     $digest
 }
 
-sub get_count
-{
+sub get_count {
     my $self = shift;
     my ($file, $criterion) = @_;
     $self->{count}{$criterion}{$file}
 }
 
-sub add_count
-{
+sub add_count {
     my $self = shift;
     # warn Carp::longmess("undefined file") unless defined $self->{file};
     return unless defined $self->{file};  # can happen during self_cover
@@ -251,8 +217,7 @@ sub add_count
      !$self->reuse($self->{file}) || $self->{additional})
 }
 
-sub delete_file
-{
+sub delete_file {
     my $self = shift;
     my ($file) = @_;
     delete $self->{f}{$file};
@@ -260,23 +225,19 @@ sub delete_file
 
 # TODO - concurrent runs updating structure?
 
-sub write
-{
+sub write {
     my $self = shift;
     my ($dir) = @_;
     # print STDERR Dumper $self;
     $dir .= "/structure";
-    unless (mkdir $dir)
-    {
+    unless (mkdir $dir) {
         confess "Can't mkdir $dir: $!" unless -d $dir;
     }
-    for my $file (sort keys %{$self->{f}})
-    {
+    for my $file (sort keys %{$self->{f}}) {
         $self->{f}{$file}{file} = $file;
         my $digest = $self->{f}{$file}{digest};
         $digest = $1 if defined $digest && $digest =~ /(.*)/; # ie tainting.
-        unless ($digest)
-        {
+        unless ($digest) {
             print STDERR "Can't find digest for $file"
                 unless $Devel::Cover::Silent ||
                        $file =~ $Devel::Cover::DB::Ignore_filenames ||
@@ -314,8 +275,7 @@ sub write
     }
 }
 
-sub read
-{
+sub read {
     my $self     = shift;
     my ($digest) = @_;
     my $file     = "$self->{base}/structure/$digest";
@@ -332,20 +292,16 @@ sub read
             }
         }
     }
-    my $d        = $self->digest($s->{file});
+    my $d = $self->digest($s->{file});
     # print STDERR "reading $digest from $file: ", Dumper $s;
     if (!$d) {
         # No digest implies that we can't read the file. Likely this is because
         # it's stored with a relative path. In which case, it's not valid to
         # assume that the file has been changed, and hence that we need to
         # "update" the structure database on disk.
-    }
-    elsif ($d eq $s->{digest})
-    {
+    } elsif ($d eq $s->{digest}) {
         $self->{f}{$s->{file}} = $s;
-    }
-    else
-    {
+    } else {
         print STDERR "Devel::Cover: Deleting old coverage ",
                      "for changed file $s->{file}\n";
         if (unlink $file) {
@@ -364,14 +320,12 @@ sub read
     $self
 }
 
-sub read_all
-{
+sub read_all {
     my ($self) = @_;
     my $dir = $self->{base};
     $dir .= "/structure";
     opendir D, $dir or return;
-    for my $d (sort grep $_ !~ /\./, readdir D)
-    {
+    for my $d (sort grep $_ !~ /\./, readdir D) {
         $d = $1 if $d =~ /(.*)/; # Die tainting.
         $self->read($d);
     }
@@ -379,8 +333,7 @@ sub read_all
     $self
 }
 
-sub merge
-{
+sub merge {
     my $self   = shift;
     my ($from) = @_;
     Devel::Cover::DB::_merge_hash($self->{f}, $from->{f});
@@ -396,7 +349,7 @@ Devel::Cover::DB::Structure - Internal: abstract structure of a source file
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
