@@ -10,33 +10,33 @@ package Devel::Cover::Util;
 use strict;
 use warnings;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
-use Cwd 'abs_path';
+use Cwd "abs_path";
 use File::Spec;
-use base 'Exporter';
+use base "Exporter";
 
 our @EXPORT_OK = qw( remove_contained_paths );
 
 sub remove_contained_paths {
-    my ( $container, @paths ) = @_;
+    my ($container, @paths) = @_;
 
     # File::Spec's case tolerancy detection on *nix/Mac systems does not
     # take actual file system properties into account, but is better than
     # trying to normalize paths with per-os logic. On Windows it is
     # properly determined per drive.
-    my ( $drive ) = File::Spec->splitpath( $container );
-    my $ignore_case = '(?i)';
-    $ignore_case = '' if !File::Spec->case_tolerant( $drive );
+    my ($drive) = File::Spec->splitpath($container);
+    my $ignore_case = "(?i)";
+    $ignore_case = "" if !File::Spec->case_tolerant($drive);
 
-    my $regex = qr@
+    my $regex = qr[
       $ignore_case      # ignore case on tolerant filesystems
       ^                 # string to match starts with:
       \Q$container\E    # path, meta-quoted for safety
       ($|/)             # followed by either the end of the string, or another
                         # slash, to avoid removing paths in directories named
                         # similar to the container
-    @x;
+    ]x;
 
     @paths = grep {
         my $path = abs_path $_;    # normalize backslashes
@@ -56,7 +56,7 @@ Devel::Cover::Util - Utility subroutines for Devel::Cover
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
