@@ -12,7 +12,7 @@ package Devel::Cover::Web;
 use strict;
 use warnings;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 use Exporter;
 
@@ -21,12 +21,10 @@ our @EXPORT_OK = "write_file";
 
 my %Files;
 
-sub write_file
-{
+sub write_file {
     my ($directory, $file) = @_;
 
-    while (my($f, $contents) = each %Files)
-    {
+    while (my ($f, $contents) = each %Files) {
         next if
             $file ne "all" &&
             (($file eq "js" || $file eq "css") && $f !~ /\.$file$/) &&
@@ -906,7 +904,7 @@ Devel::Cover::Web - Files for JavaScript or CSS
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
